import { useQuery, queryCache } from 'react-query'
import { useClient } from '@context/auth'
import logoPlaceholder from '@public/assets/logo.svg'

const skeletonFormat = {
  title: 'Laden...',
  example_image: [{ url: logoPlaceholder }],
  isLoading: true,
  error: null,
  isError: false,
  articles: [],
  example: {
    title: 'Example laden...',
    example_image: [{ url: logoPlaceholder }],
    description:
      'A handcrafted, small-batch, artisinal pour-over version of the classic lorem ipsum generator.',
  },
}

const skeletonData = Array.from({ length: 10 }, (v, index) => ({
  id: `loading-example-${index}`,
  ...skeletonFormat,
}))

const exampleQueryConfig = {
  staleTime: 1000 * 60 * 60,
  cacheTime: 1000 * 60 * 60,
}

const getExamplesConfig = (client) => ({
  queryKey: 'examples',
  queryFn: () => client('examples').then((res) => res),
  config: {
    onSuccess(examples) {
      for (const example of examples) {
        queryCache.setQueryData(
          ['example', { exampleId: example.id }],
          example,
          exampleQueryConfig
        )
      }
    },
  },
})

// Get All Examples
function useExamples() {
  const client = useClient()
  const result = useQuery(getExamplesConfig(client))

  return { ...result, examples: result.data ?? skeletonData }
}

// Get Category By Its ID
function useCategory(exampleId) {
  const client = useClient()
  const result = useQuery({
    queryKey: ['example', { exampleId }],
    queryFn: () => client(`examples/${exampleId}`).then((res) => res),
    ...exampleQueryConfig,
  })

  const { data, ...response } = result

  if (data && data[0]) {
    let { articles, locations, ...example } = data[0]

    return { articles: data[0].articles, example, ...response }
  } else if (data && typeof data === 'object') {
    let { articles, locations, ...example } = data

    return { articles, example, ...response }
  } else {
    return {
      articles: skeletonData,
      example: skeletonFormat.example,
      ...result,
    }
  }
}

function setQueryDataForCategory(example) {
  queryCache.setQueryData({
    queryKey: ['example', { exampleId: example.id }],
    queryFn: example,
    ...exampleQueryConfig,
  })
}

export { useCategory, useExamples, setQueryDataForCategory }
